summaryrefslogtreecommitdiff
path: root/client/src/leap/soledad/client/_secrets/__init__.py
diff options
context:
space:
mode:
Diffstat (limited to 'client/src/leap/soledad/client/_secrets/__init__.py')
-rw-r--r--client/src/leap/soledad/client/_secrets/__init__.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/client/src/leap/soledad/client/_secrets/__init__.py b/client/src/leap/soledad/client/_secrets/__init__.py
index 26294364..69c9141f 100644
--- a/client/src/leap/soledad/client/_secrets/__init__.py
+++ b/client/src/leap/soledad/client/_secrets/__init__.py
@@ -43,7 +43,7 @@ class Secrets(EmitMixin):
'local_secret': 448, # local_secret to derive a local_key for storage
}
- def __init__(self, uuid, passphrase, url, local_path, creds, userid,
+ def __init__(self, uuid, passphrase, url, local_path, get_token, userid,
shared_db=None):
self._uuid = uuid
self._passphrase = passphrase
@@ -51,7 +51,7 @@ class Secrets(EmitMixin):
self._secrets = {}
self.crypto = SecretsCrypto(self.get_passphrase)
self.storage = SecretsStorage(
uuid, self.get_passphrase, url, local_path, creds, userid,
shared_db=shared_db)
self._bootstrap()
@@ -51,7 +51,7 @@ class Secrets(EmitMixin):
self.crypto = SecretsCrypto(self.get_passphrase)
self.storage = SecretsStorage(
- uuid, self.get_passphrase, url, local_path, creds, userid,
+ uuid, self.get_passphrase, url, local_path, get_token, userid,
shared_db=shared_db)
self._bootstrap()